#include <stdio.h>

#include <aos/aos.h>
#include <aos/capabilities.h>
#include <aos/ram_alloc.h>
#include <aos/aos_rpc.h>
#include <mm/mm.h>
#include <grading.h>
#include <spawn/spawn.h>

#include <test_helper.h>
#include <test_mm.h>
#include <test_paging.h>
#include <test_spawn.h>

void
grading_setup_bsp_init(int argc, char **argv) {
}

void
grading_setup_app_init(struct bootinfo * bi) {
}

void
grading_setup_noninit(int *argc, char ***argv) {
}

void
grading_test_mm(struct mm *test) {
  testmm = test;

  // do_test_mm();
  // do_test_paging();
}

void
grading_test_early(void) {
  do_test_spawn();
}

void
grading_test_late(void) {
}
